@@ -24,8 +24,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPluginFactory>
-#include <memory>
-#include <qqmlengine.h>
+#include <QQmlEngine>
 
 #include "quick/kquickconfigmodule.h"
 
