@@ -186,6 +186,7 @@ import org.kde.kcmutils as KCMUtils
 Kirigami.ApplicationItem {
     // force it to *never* try to resize itself
     width: Window.width
+    height: Window.height
 
     implicitWidth: Math.max(pageStack.implicitWidth, Kirigami.Units.gridUnit * 36)
     implicitHeight: Math.max(pageStack.implicitHeight, Kirigami.Units.gridUnit * 20)
@@ -203,7 +204,7 @@ Kirigami.ApplicationItem {
     pageStack.separatorVisible: pageStack.depth > 0 && (pageStack.items[0].sidebarMode ?? false)
     pageStack.globalToolBar.preferredHeight: toolButton.implicitHeight + Kirigami.Units.smallSpacing * 2
     pageStack.globalToolBar.style: Kirigami.ApplicationHeaderStyle.ToolBar
-    pageStack.globalToolBar.showNavigationButtons: pageStack.currentIndex > 0 ? Kirigami.ApplicationHeaderStyle.ShowBackButton : Kirigami.ApplicationHeaderStyle.NoNavigationButtons
+    pageStack.globalToolBar.showNavigationButtons: Kirigami.ApplicationHeaderStyle.ShowBackButton
 
     pageStack.columnView.columnResizeMode: pageStack.items.length > 0 && (pageStack.items[0].Kirigami.ColumnView.fillWidth || pageStack.items.filter(item => item.visible).length === 1)
         ? Kirigami.ColumnView.SingleColumn
